========================
Geometric Algebra Module
========================

.. automodule:: sympy.galgebra

Documentation for Geometric Algebra module.

Contents:

.. toctree::
   :maxdepth: 2

   ga.rst
   manifold.rst
   vector.rst
   precedence.rst
   printing.rst
   ncutil.rst
   stringarrays.rst
   debug.rst
